@@ -1,4 +1,4 @@
-// Copyright (C) 2017-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2017-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -105,31 +105,31 @@ TEST(ParserTest, nestedLists) {
 
 TEST(ParserTest, listsInMaps) {
     string txt = "{ \"constellations\": { \"orion\": [ \"rigel\", \"betelgeuse\" ], "
-                    "\"cygnus\": [ \"deneb\", \"albireo\"] } }";
+                 "\"cygnus\": [ \"deneb\", \"albireo\"] } }";
     testParser(txt, ParserContext::PARSER_JSON);
 }
 
 TEST(ParserTest, mapsInLists) {
-    string txt = "[ { \"body\": \"earth\", \"gravity\": 1.0 },"
-                 " { \"body\": \"mars\", \"gravity\": 0.376 } ]";
+    string txt = "[ { \"body\": \"earth\", \"gravity\": 1.0 }, "
+                 "{ \"body\": \"mars\", \"gravity\": 0.376 } ]";
     testParser(txt, ParserContext::PARSER_JSON);
 }
 
 TEST(ParserTest, types) {
-    string txt = "{ \"string\": \"foo\","
-                   "\"integer\": 42,"
-                   "\"boolean\": true,"
-                   "\"map\": { \"foo\": \"bar\" },"
-                   "\"list\": [ 1, 2, 3 ],"
-                   "\"null\": null }";
+    string txt = "{ \"string\": \"foo\", "
+                 "\"integer\": 42, "
+                 "\"boolean\": true, "
+                 "\"map\": { \"foo\": \"bar\" }, "
+                 "\"list\": [ 1, 2, 3 ], "
+                 "\"null\": null }";
     testParser(txt, ParserContext::PARSER_JSON);
 }
 
 TEST(ParserTest, keywordJSON) {
-    string txt = "{ \"name\": \"user\","
-                   "\"type\": \"password\","
-                   "\"user\": \"name\","
-                   "\"password\": \"type\" }";
+    string txt = "{ \"name\": \"user\", "
+                 "\"type\": \"password\", "
+                 "\"user\": \"name\", "
+                 "\"password\": \"type\" }";
     testParser(txt, ParserContext::PARSER_JSON);
 }
 
@@ -142,15 +142,15 @@ TEST(ParserTest, keywordAgent) {
         "    \"control-sockets\": {"
         "        \"dhcp4\": {"
         "            \"socket-type\": \"unix\","
-        "            \"socket-name\": \"kea4-ctrl-socket\""
+        "            \"socket-name\": \"/tmp/kea4-ctrl-socket\""
         "        },"
         "        \"dhcp6\": {"
         "            \"socket-type\": \"unix\","
-        "            \"socket-name\": \"kea6-ctrl-socket\""
+        "            \"socket-name\": \"/tmp/kea6-ctrl-socket\""
         "        },"
         "        \"d2\": {"
         "            \"socket-type\": \"unix\","
-        "            \"socket-name\": \"kea-ddns-ctrl-socket\""
+        "            \"socket-name\": \"/tmp/kea-ddns-ctrl-socket\""
         "        }"
         "    },"
         "    \"hooks-libraries\": ["
@@ -179,15 +179,15 @@ TEST(ParserTest, keywordSubAgent) {
         "    \"control-sockets\": {"
         "        \"dhcp4\": {"
         "            \"socket-type\": \"unix\","
-        "            \"socket-name\": \"kea4-ctrl-socket\""
+        "            \"socket-name\": \"/tmp/kea4-ctrl-socket\""
         "        },"
         "        \"dhcp6\": {"
         "            \"socket-type\": \"unix\","
-        "            \"socket-name\": \"kea6-ctrl-socket\""
+        "            \"socket-name\": \"/tmp/kea6-ctrl-socket\""
         "        },"
         "        \"d2\": {"
         "            \"socket-type\": \"unix\","
-        "            \"socket-name\": \"kea-ddns-ctrl-socket\""
+        "            \"socket-name\": \"/tmp/kea-ddns-ctrl-socket\""
         "        }"
         "    },"
         "    \"hooks-libraries\": ["
@@ -208,45 +208,44 @@ TEST(ParserTest, keywordSubAgent) {
 // Tests if bash (#) comments are supported. That's the only comment type that
 // was supported by the old parser.
 TEST(ParserTest, bashComments) {
-    string txt= "{ \"Control-agent\": {"
-                "  \"http-host\": \"localhost\","
-                "  \"http-port\": 9000,\n"
-                "  \"control-sockets\": {\n"
-                "    \"d2\": {\n"
-                "# this is a comment\n"
-                "\"socket-type\": \"unix\", \n"
-                "# This socket is mine. I can name it whatever\n"
-                "# I like, ok?\n"
-                "\"socket-name\": \"Hector\" \n"
-                "} } } }";
+    string txt = "{ \"Control-agent\": {\n"
+                 "  \"http-host\": \"localhost\",\n"
+                 "  \"http-port\": 9000,\n"
+                 "  \"control-sockets\": {\n"
+                 "    \"d2\": {\n"
+                 "# this is a comment\n"
+                 "        \"socket-type\": \"unix\", \n"
+                 "# This socket is mine. I can name it whatever\n"
+                 "# I like, ok?\n"
+                 "        \"socket-name\": \"Hector\" \n"
+                 "} } } }";
     testParser(txt, ParserContext::PARSER_AGENT);
 }
 
 // Tests if C++ (//) comments can start anywhere, not just in the first line.
 TEST(ParserTest, cppComments) {
-    string txt= "{ \"Control-agent\": {"
-                "  \"http-host\": \"localhost\","
-                "  \"http-port\": 9001, // the level is over 9000!\n"
-                "  \"control-sockets\": {\n"
-                "    // Let's try talking to D2. Sadly, it never talks"
-                "    // to us back :( Maybe he doesn't like his name?\n"
-                "    \"d2\": {"
-                "\"socket-type\": \"unix\", \n"
-                "\"socket-name\": \"Hector\" \n"
-                "} } } }";
-
+    string txt = "{ \"Control-agent\": {\n"
+                 "  \"http-host\": \"localhost\",\n"
+                 "  \"http-port\": 9001, // the level is over 9000!\n"
+                 "  \"control-sockets\": {\n"
+                 "    // Let's try talking to D2. Sadly, it never talks"
+                 "    // to us back :( Maybe he doesn't like his name?\n"
+                 "    \"d2\": {"
+                 "        \"socket-type\": \"unix\", \n"
+                 "        \"socket-name\": \"Hector\" \n"
+                 "} } } }";
     testParser(txt, ParserContext::PARSER_AGENT, false);
 }
 
 // Tests if bash (#) comments can start anywhere, not just in the first line.
 TEST(ParserTest, bashCommentsInline) {
-    string txt= "{ \"Control-agent\": {"
-                "  \"http-host\": \"localhost\","
+    string txt= "{ \"Control-agent\": {\n"
+                "  \"http-host\": \"localhost\",\n"
                 "  \"http-port\": 9000,\n"
                 "  \"control-sockets\": {\n"
                 "    \"d2\": {"
-                "\"socket-type\": \"unix\", # Maybe Hector is not really a \n"
-                "\"socket-name\": \"Hector\" # Unix process?\n"
+                "        \"socket-type\": \"unix\", # Maybe Hector is not really a \n"
+                "        \"socket-name\": \"Hector\" # Unix process?\n"
                 "# Oh no! He's a windows one and just pretending!\n"
                 "} } } }";
     testParser(txt, ParserContext::PARSER_AGENT, false);
@@ -254,35 +253,46 @@ TEST(ParserTest, bashCommentsInline) {
 
 // Tests if multi-line C style comments are handled correctly.
 TEST(ParserTest, multilineComments) {
-    string txt= "{ \"Control-agent\": {"
-                "  \"http-host\": \"localhost\","
-                "  \"http-port\": 9000,\n"
-                "  \"control-sockets\": {\n"
-                "    \"dhcp4\": {\n"
-                "        \"socket-type\": \"unix\"\n"
-                "    }\n"
-                "  /* Ok, forget about it. If Hector doesn't want to talk,\n"
-                "     we won't talk to him either. We now have quiet days. */\n"
-                "  /* \"d2\": {"
-                "  \"socket-type\": \"unix\",\n"
-                "\"socket-name\": \"Hector\"\n"
-                "}*/ } } }";
+    string txt = "{ \"Control-agent\": {\n"
+                 "  \"http-host\": \"localhost\",\n"
+                 "  \"http-port\": 9000,\n"
+                 "  \"control-sockets\": {\n"
+                 "    \"dhcp4\": {\n"
+                 "        \"socket-type\": \"unix\"\n"
+                 "    }\n"
+                 "  /* Ok, forget about it. If Hector doesn't want to talk,\n"
+                 "     we won't talk to him either. We now have quiet days. */\n"
+                 "  /* \"d2\": {"
+                 "         \"socket-type\": \"unix\",\n"
+                 "         \"socket-name\": \"Hector\"\n"
+                 "}*/ } } }";
     testParser(txt, ParserContext::PARSER_AGENT, false);
 }
 
 // Tests if embedded comments are handled correctly.
 TEST(ParserTest, embbededComments) {
-    string txt= "{ \"Control-agent\": {"
-                "  \"comment\": \"a comment\","
-                "  \"http-host\": \"localhost\","
-                "  \"http-port\": 9000,\n"
-                "  \"control-sockets\": {\n"
-                "    \"dhcp4\": {\n"
-                "        \"user-context\": { \"comment\": \"indirect\" },\n"
-                "        \"socket-type\": \"unix\"\n"
-                "    } },\n"
-                "  \"user-context\": { \"compatible\": true }\n"
-                "} }";
+    string txt = "{ \"Control-agent\": {\n"
+                 "  \"comment\": \"a comment\",\n"
+                 "  \"http-host\": \"localhost\",\n"
+                 "  \"http-port\": 9000,\n"
+                 "  \"control-sockets\": {\n"
+                 "    \"dhcp4\": {\n"
+                 "        \"user-context\": { \"comment\": \"indirect\" },\n"
+                 "        \"socket-type\": \"unix\"\n"
+                 "    } },\n"
+                 "  \"user-context\": { \"compatible\": true }\n"
+                 "} }";
+    testParser(txt, ParserContext::PARSER_AGENT, false);
+}
+
+// Test that output-options is an alias of output_options.
+TEST(ParserTest, outputDashOptions) {
+    string txt = "{ \"Control-agent\": {"
+                 " \"loggers\": [ { "
+                 "     \"name\": \"kea-ctrl-agent\","
+                 "     \"output-options\": [ { \"output\": \"stdout\" } ],"
+                 "     \"severity\": \"INFO\" } ]"
+                 "} }";
     testParser(txt, ParserContext::PARSER_AGENT, false);
 }
 
@@ -884,15 +894,15 @@ TEST_F(TrailingCommasTest, tests) {
   "Control-agent": {
     "control-sockets": {
       "d2": {
-        "socket-name": "kea-dhcp-ddns-ctrl.sock",
+        "socket-name": "/tmp/kea-dhcp-ddns-ctrl.sock",
         "socket-type": "unix",
       },
       "dhcp4": {
-        "socket-name": "kea-dhcp4-ctrl.sock",
+        "socket-name": "/tmp/kea-dhcp4-ctrl.sock",
         "socket-type": "unix",
       },
       "dhcp6": {
-        "socket-name": "kea-dhcp6-ctrl.sock",
+        "socket-name": "/tmp/kea-dhcp6-ctrl.sock",
         "socket-type": "unix",
       },
     },
