@@ -1,4 +1,4 @@
-// Copyright (C) 2013-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2013-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -9,7 +9,6 @@
 #include <asiolink/io_address.h>
 #include <cc/data.h>
 #include <cc/command_interpreter.h>
-#include <config/unix_command_config.h>
 #include <dhcp4/json_config_parser.h>
 #include <dhcp4/tests/dhcp4_test_utils.h>
 #include <dhcp/libdhcp++.h>
@@ -34,7 +33,6 @@ using namespace std;
 using namespace isc::asiolink;
 using namespace isc::data;
 using namespace isc::util;
-using namespace isc::config;
 
 namespace isc {
 namespace dhcp {
@@ -42,7 +40,7 @@ namespace test {
 
 BaseServerTest::BaseServerTest()
     : original_datadir_(CfgMgr::instance().getDataDir()) {
-    CfgMgr::instance().getDataDir(true, TEST_DATA_BUILDDIR);
+    CfgMgr::instance().setDataDir(TEST_DATA_BUILDDIR);
 }
 
 BaseServerTest::~BaseServerTest() {
@@ -52,7 +50,7 @@ BaseServerTest::~BaseServerTest() {
     static_cast<void>(::remove(s2.str().c_str()));
 
     // Revert to original data directory.
-    CfgMgr::instance().getDataDir(true, original_datadir_);
+    CfgMgr::instance().setDataDir(original_datadir_);
 
     // Revert to unit test logging, in case the test reconfigured it.
     isc::log::initLogger();
@@ -90,7 +88,6 @@ Dhcpv4SrvTest::Dhcpv4SrvTest()
 }
 
 Dhcpv4SrvTest::~Dhcpv4SrvTest() {
-    resetSocketPath();
     // Make sure that we revert to default value
     CfgMgr::instance().clear();
 
@@ -103,21 +100,6 @@ Dhcpv4SrvTest::~Dhcpv4SrvTest() {
     MultiThreadingMgr::instance().apply(false, 0, 0);
 }
 
-void
-Dhcpv4SrvTest::setSocketTestPath(const std::string explicit_path /* = "" */) {
-    UnixCommandConfig::getSocketPath(true, (!explicit_path.empty() ?
-                                            explicit_path : TEST_DATA_BUILDDIR));
-
-    auto path = UnixCommandConfig::getSocketPath();
-    UnixCommandConfig::setSocketPathPerms(file::getPermissions(path));
-}
-
-void
-Dhcpv4SrvTest::resetSocketPath() {
-    UnixCommandConfig::getSocketPath(true);
-    UnixCommandConfig::setSocketPathPerms();
-}
-
 void Dhcpv4SrvTest::addPrlOption(Pkt4Ptr& pkt) {
 
     OptionUint8ArrayPtr option_prl =
