@@ -1,4 +1,4 @@
-// Copyright (C) 2015-2021 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2015-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -155,7 +155,7 @@ public:
     /// @note The optional position for an error in a string begins by 1
     /// so the caller should add 1 to the position of the C++ string.
     ///
-    /// @param loc location within the parsed file when experienced a problem.
+    /// @param loc location within the parsed file where the problem was experienced.
     /// @param what string explaining the nature of the error.
     /// @param pos optional position for in string errors.
     /// @throw Dhcp6ParseError
@@ -214,6 +214,21 @@ public:
     void unique(const std::string& name,
                 isc::data::Element::Position loc);
 
+    /// @brief Warning handler
+    ///
+    /// @param loc location within the parsed file where the problem was experienced
+    /// @param what string explaining the nature of the error
+    ///
+    /// @throw ParseError
+    void warning(const isc::dhcp::location& loc, const std::string& what);
+
+    /// @brief Warning for extra commas
+    ///
+    /// @param loc location within the parsed file of the extra comma
+    ///
+    /// @throw ParseError
+    void warnAboutExtraCommas(const isc::dhcp::location& loc);
+
     /// @brief Defines syntactic contexts for lexical tie-ins
     typedef enum {
         ///< This one is used in pure JSON mode.
@@ -324,8 +339,13 @@ public:
         CONFIG_CONTROL,
 
         /// Used while parsing config-control/config-databases
-        CONFIG_DATABASE
+        CONFIG_DATABASE,
 
+        /// Used while parsing compatibility parameters
+        COMPATIBILITY,
+
+        /// Used while parsing Dhcp6/ddns-conflict-resolution-mode.
+        DDNS_CONFLICT_RESOLUTION_MODE,
     } ParserContext;
 
     /// @brief File name
