@@ -1,4 +1,4 @@
-// Copyright (C) 2018-2022 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2018-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -14,6 +14,7 @@
 #include <testutils/gtest_utils.h>
 #include <testutils/io_utils.h>
 #include <testutils/log_utils.h>
+#include <testutils/test_to_element.h>
 #include <testutils/user_context_utils.h>
 
 #include <iostream>
@@ -39,7 +40,11 @@ namespace test {
 void compareJSON(ConstElementPtr a, ConstElementPtr b) {
     ASSERT_TRUE(a);
     ASSERT_TRUE(b);
-    EXPECT_EQ(a->str(), b->str());
+    EXPECT_EQ(a->str(), b->str())
+#ifdef HAVE_CREATE_UNIFIED_DIFF
+        << "\nDiff:\n" << generateDiff(prettyPrint(a), prettyPrint(b)) << "\n"
+#endif
+    ;
 }
 
 /// @brief Tests if the input string can be parsed with specific parser
@@ -102,31 +107,31 @@ TEST(ParserTest, nestedLists) {
 
 TEST(ParserTest, listsInMaps) {
     string txt = "{ \"constellations\": { \"orion\": [ \"rigel\", \"betelgeuse\" ], "
-                    "\"cygnus\": [ \"deneb\", \"albireo\"] } }";
+                 "\"cygnus\": [ \"deneb\", \"albireo\"] } }";
     testParser(txt, ParserContext::PARSER_JSON);
 }
 
 TEST(ParserTest, mapsInLists) {
-    string txt = "[ { \"body\": \"earth\", \"gravity\": 1.0 },"
-                 " { \"body\": \"mars\", \"gravity\": 0.376 } ]";
+    string txt = "[ { \"body\": \"earth\", \"gravity\": 1.0 }, "
+                 "{ \"body\": \"mars\", \"gravity\": 0.376 } ]";
     testParser(txt, ParserContext::PARSER_JSON);
 }
 
 TEST(ParserTest, types) {
-    string txt = "{ \"string\": \"foo\","
-                   "\"integer\": 42,"
-                   "\"boolean\": true,"
-                   "\"map\": { \"foo\": \"bar\" },"
-                   "\"list\": [ 1, 2, 3 ],"
-                   "\"null\": null }";
+    string txt = "{ \"string\": \"foo\", "
+                 "\"integer\": 42, "
+                 "\"boolean\": true, "
+                 "\"map\": { \"foo\": \"bar\" }, "
+                 "\"list\": [ 1, 2, 3 ], "
+                 "\"null\": null }";
     testParser(txt, ParserContext::PARSER_JSON);
 }
 
 TEST(ParserTest, keywordJSON) {
-    string txt = "{ \"name\": \"user\","
-                   "\"type\": \"password\","
-                   "\"user\": \"name\","
-                   "\"password\": \"type\" }";
+    string txt = "{ \"name\": \"user\", "
+                 "\"type\": \"password\", "
+                 "\"user\": \"name\", "
+                 "\"password\": \"type\" }";
     testParser(txt, ParserContext::PARSER_JSON);
 }
 
@@ -252,7 +257,6 @@ TEST(ParserTest, keywordSubNetconf) {
         "    }"
         "   ]"
         "}";
-
     // This is only a subset of full config, so we'll parse with PARSER_SUB_NETCONF.
     testParser(txt, ParserContext::PARSER_SUB_NETCONF);
     testParser(txt, ParserContext::PARSER_JSON);
@@ -264,13 +268,13 @@ TEST(ParserTest, bashComments) {
     string txt= "{ \"Netconf\": {"
                 "  \"managed-servers\": {\n"
                 "    \"d2\": {\n"
-                "      \"model\": \"foo\",\n"
-                "      \"control-socket\": {\n"
+                "        \"model\": \"foo\",\n"
+                "        \"control-socket\": {\n"
                 "# this is a comment\n"
-                "\"socket-type\": \"unix\", \n"
+                "            \"socket-type\": \"unix\", \n"
                 "# This socket is mine. I can name it whatever\n"
                 "# I like, ok?\n"
-                "\"socket-name\": \"Hector\" \n"
+                "            \"socket-name\": \"Hector\" \n"
                 "} } } } }";
     testParser(txt, ParserContext::PARSER_NETCONF);
 }
@@ -282,12 +286,11 @@ TEST(ParserTest, cppComments) {
                 "    // Let's try talking to D2. Sadly, it never talks"
                 "    // to us back :( Maybe he doesn't like his name?\n"
                 "    \"d2\": {\n"
-                "      \"model\": \"foo\",\n"
-                "      \"control-socket\": {\n"
-                "\"socket-type\": \"unix\", \n"
-                "\"socket-name\": \"Hector\" \n"
+                "        \"model\": \"foo\",\n"
+                "        \"control-socket\": {\n"
+                "            \"socket-type\": \"unix\", \n"
+                "            \"socket-name\": \"Hector\" \n"
                 "} } } } }";
-
     testParser(txt, ParserContext::PARSER_NETCONF, false);
 }
 
@@ -296,10 +299,10 @@ TEST(ParserTest, bashCommentsInline) {
     string txt= "{ \"Netconf\": {"
                 "  \"managed-servers\": {\n"
                 "    \"d2\": {\n"
-                "      \"model\": \"foo\",\n"
-                "      \"control-socket\": {\n"
-                "\"socket-type\": \"unix\", # Maybe Hector is not really a \n"
-                "\"socket-name\": \"Hector\" # Unix process?\n"
+                "        \"model\": \"foo\",\n"
+                "        \"control-socket\": {\n"
+                "            \"socket-type\": \"unix\", # Maybe Hector is not really a \n"
+                "            \"socket-name\": \"Hector\" # Unix process?\n"
                 "# Oh no! He's a windows one and just pretending!\n"
                 "} } } } }";
     testParser(txt, ParserContext::PARSER_NETCONF, false);
@@ -318,10 +321,10 @@ TEST(ParserTest, multilineComments) {
                 "  /* Ok, forget about it. If Hector doesn't want to talk,\n"
                 "     we won't talk to him either. We now have quiet days. */\n"
                 "  /* \"d2\": {"
-                "  \"model\": \"bar\",\n"
-                "  \"control-socket\": {\n"
-                "  \"socket-type\": \"unix\",\n"
-                "\"socket-name\": \"Hector\"\n"
+                "         \"model\": \"bar\",\n"
+                "         \"control-socket\": {\n"
+                "             \"socket-type\": \"unix\",\n"
+                "             \"socket-name\": \"Hector\"\n"
                 "} }*/ } } }";
     testParser(txt, ParserContext::PARSER_NETCONF, false);
 }
@@ -332,15 +335,26 @@ TEST(ParserTest, embbededComments) {
                 "  \"comment\": \"a comment\","
                 "  \"managed-servers\": {\n"
                 "    \"dhcp4\": {\n"
-                "      \"control-socket\": {\n"
-                "        \"user-context\": { \"comment\": \"indirect\" },\n"
-                "        \"socket-type\": \"stdout\"\n"
+                "        \"control-socket\": {\n"
+                "            \"user-context\": { \"comment\": \"indirect\" },\n"
+                "            \"socket-type\": \"stdout\"\n"
                 "    } } },\n"
                 "  \"user-context\": { \"compatible\": true }\n"
                 "} }";
     testParser(txt, ParserContext::PARSER_NETCONF, false);
 }
 
+// Test that output-options is an alias of output_options.
+TEST(ParserTest, outputDashOptions) {
+    string txt= "{ \"Netconf\": {"
+                " \"loggers\": [ { "
+                "     \"name\": \"kea-netconf\","
+                "     \"output-options\": [ { \"output\": \"stdout\" } ],"
+                "     \"severity\": \"INFO\" } ]"
+                "} }";
+    testParser(txt, ParserContext::PARSER_NETCONF, false);
+}
+
 /// @brief Loads specified example config file
 ///
 /// This test loads specified example file twice: first, using the legacy
