@@ -1,4 +1,4 @@
-// Copyright (C) 2013-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2013-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -42,7 +42,7 @@ const char *valid_msgs[] =
      " \"dhcid\" : \"010203040A7F8E3D\" , "
      " \"lease-expires-on\" : \"20130121132405\" , "
      " \"lease-length\" : 1300, "
-     " \"use-conflict-resolution\": true"
+     " \"conflict-resolution-mode\": \"check-with-dhcid\""
      "}",
     // Valid Remove.
      "{"
@@ -54,7 +54,7 @@ const char *valid_msgs[] =
      " \"dhcid\" : \"010203040A7F8E3D\" , "
      " \"lease-expires-on\" : \"20130121132405\" , "
      " \"lease-length\" : 1300, "
-     " \"use-conflict-resolution\": false"
+     " \"conflict-resolution-mode\": \"no-check-with-dhcid\""
      "}",
      // Valid Add with IPv6 address
      "{"
@@ -66,7 +66,7 @@ const char *valid_msgs[] =
      " \"dhcid\" : \"010203040A7F8E3D\" , "
      " \"lease-expires-on\" : \"20130121132405\" , "
      " \"lease-length\" : 1300, "
-     " \"use-conflict-resolution\" : true"
+     " \"conflict-resolution-mode\": \"check-with-dhcid\""
      "}"
 };
 
@@ -258,7 +258,9 @@ TEST_F(NameChangeUDPListenerTest, basicReceiveTests) {
         EXPECT_EQ(NameChangeListener::SUCCESS, result_);
 
         // Verify the received request matches the sent request.
-        EXPECT_TRUE(checkSendVsReceived(sent_ncr_, received_ncr_));
+        EXPECT_TRUE(checkSendVsReceived(sent_ncr_, received_ncr_))
+            << "sent_ncr_" << (sent_ncr_ ? sent_ncr_->toText() : "<null>")
+            << "recv_ncr_ " << (received_ncr_ ? received_ncr_->toText() : "<null>");
     }
 
     // Verify we can gracefully stop listening.
@@ -1020,6 +1022,55 @@ public:
         io_service_.stop();
         FAIL() << "Test timeout hit.";
     }
+
+    /// @brief checks the received NCR content, ignoring the order if necessary.
+    ///
+    /// The UDP does not provide any guarantees regarding order. While in most cases
+    /// the NCRs are received in the order they're sent, that's not guaranteed. As such,
+    /// the test does the normal ordered check, which will pass in most cases. However,
+    /// we have documented Jenkins history that it sometimes fail. In those cases, we
+    /// need to go through a full check assuming the packets were received not in order.
+    /// If that fails, the test will print detailed information about the failure.
+    ///
+    /// This function returns a status, but it's not really necessary to check it as
+    /// it calls gtest macros to indicate failures.
+    ///
+    /// @param num_msgs number of received and sent messages
+    /// @param sent vector of sent NCRs
+    /// @param rcvd vector of received NCRs
+    /// @return true if all packets were received, false otherwise
+    bool checkUnordered(size_t num_msgs, const std::vector<NameChangeRequestPtr>& sent,
+                      const std::vector<NameChangeRequestPtr>& rcvd) {
+        // Verify that what we sent matches what we received.
+        // WRONG ASSUMPTION HERE: UDP does not guarantee ordered delivery.
+        bool ok = true;
+        for (int i = 0; i < num_msgs; i++) {
+            if (!checkSendVsReceived(sent[i], rcvd[i])) {
+                // Ok, the data was not received in order.
+                ok = false;
+                break;
+            }
+        }
+        if (!ok) {
+            std::cout << "UDP data received not in order! Checking un ordered delivery"
+                      << std::endl;
+            // We need to double iterate through the messages to check every one
+            // against one another.
+            for (int i = 0; i < num_msgs; i++) {
+                ok = false;
+                for (int j = 0; j < num_msgs; j++) {
+                    if (checkSendVsReceived(sent[i], rcvd[j])) {
+                        std::cout << "Found UDP packet " << i << ", received as " << j << "th"
+                                  << std::endl;
+                        ok = true;
+                    }
+                }
+                EXPECT_TRUE(ok) << "failed to find UDP packet " << i << " among total of "
+                                << num_msgs << " messages received";
+            }
+        }
+        return (ok);
+    }
 };
 
 /// @brief Uses a sender and listener to test UDP-based NCR delivery
@@ -1057,10 +1108,8 @@ TEST_F(NameChangeUDPTest, roundTripTest) {
     ASSERT_EQ(num_msgs, sent_ncrs_.size());
     ASSERT_EQ(num_msgs, received_ncrs_.size());
 
-    // Verify that what we sent matches what we received.
-    for (int i = 0; i < num_msgs; i++) {
-        EXPECT_TRUE (checkSendVsReceived(sent_ncrs_[i], received_ncrs_[i]));
-    }
+    // Check if the payload was received, ignoring the order if necessary.
+    checkUnordered(num_msgs, sent_ncrs_, received_ncrs_);
 
     // Verify that we can gracefully stop listening.
     EXPECT_NO_THROW(listener_->stopListening());
@@ -1113,10 +1162,9 @@ TEST_F(NameChangeUDPTest, roundTripTestMultiThreading) {
     ASSERT_EQ(num_msgs, sent_ncrs_.size());
     ASSERT_EQ(num_msgs, received_ncrs_.size());
 
-    // Verify that what we sent matches what we received.
-    for (int i = 0; i < num_msgs; i++) {
-        EXPECT_TRUE (checkSendVsReceived(sent_ncrs_[i], received_ncrs_[i]));
-    }
+    // Verify that what we sent matches what we received. Ignore the order
+    // if necessary.
+    checkUnordered(num_msgs, sent_ncrs_, received_ncrs_);
 
     // Verify that we can gracefully stop listening.
     EXPECT_NO_THROW(listener_->stopListening());
