@@ -1,4 +1,4 @@
-// Copyright (C) 2014-2022 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2014-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -30,6 +30,7 @@
 #include <cc/data.h>
 #include <cc/user_context.h>
 #include <cc/simple_parser.h>
+#include <util/optional.h>
 #include <util/strutil.h>
 
 #include <boost/shared_ptr.hpp>
@@ -140,14 +141,20 @@ public:
     /// @return True if updates should always be performed.
     bool getUpdateOnRenew() const;
 
-    /// @brief Returns whether or not keah-dhcp-ddns should use conflict resolution
+    /// @brief Returns percent of lease lifetime to use for TTL
     ///
-    /// This value is communicated to D2 via the NCR.  When true, D2 should follow
-    /// follow conflict resolution steps described in RFC 4703.  If not, it should
-    /// simple add or remove entries.
+    /// This value, if greater than zero, is used to calculate the lease lifetime
+    /// passed to D2 in the NCR.  Otherwise the value is calculated per RFC 4702.
     ///
-    /// @return True if conflict resolution should be used.
-    bool getUseConflictResolution() const;
+    /// @return TTL percent as an Optional.
+    util::Optional<double> getTtlPercent() const;
+
+    /// @brief Returns the DDNS config resolution mode for kea-dhcp-ddns
+    ///
+    /// This value is communicated to D2 via the NCR.
+    ///
+    /// @return the DDNS conflict resolution mode
+    std::string getConflictResolutionMode() const;
 
     /// @brief Returns the subnet-id of the subnet associated with these parameters
     ///
@@ -991,6 +998,21 @@ public:
         return lenient_option_parsing_;
     }
 
+    /// @brief Set ignore DHCP Server Identifier compatibility flag.
+    ///
+    /// @param value the boolean value to be set when configuring DHCP
+    /// Server Identifier usage preferences.
+    void setIgnoreServerIdentifier(bool const value) {
+        ignore_dhcp_server_identifier_ = value;
+    }
+
+    /// @brief Get ignore DHCP Server Identifier compatibility flag.
+    ///
+    /// @return the configured value for DHCP Server Identifier usage preferences.
+    bool getIgnoreServerIdentifier() const {
+        return (ignore_dhcp_server_identifier_);
+    }
+
     /// @brief Set ignore RAI Link Selection compatibility flag.
     ///
     /// @param value the boolean value to be set when configuring RAI Link
@@ -1006,6 +1028,21 @@ public:
         return ignore_rai_link_selection_;
     }
 
+    /// @brief Set exclude .0 and .255 addresses in subnets bigger than /24 flag.
+    ///
+    /// @param value the boolean value to be set when excluding .0 .255 from
+    /// subnets bigger than /24.
+    void setExcludeFirstLast24(bool const value) {
+        exclude_first_last_24_ = value;
+    }
+
+    /// @brief Get exclude .0 and .255 addresses in subnets bigger than /24 flag.
+    ///
+    /// @return the configured value for exclude .0 and .255 flag.
+    bool getExcludeFirstLast24() const {
+        return exclude_first_last_24_;
+    }
+
     /// @brief Convenience method to propagate configuration parameters through
     /// inversion of control.
     ///
@@ -1172,8 +1209,12 @@ private:
     //@{
     /// @brief Indicates whether lenient option parsing is enabled
     bool lenient_option_parsing_;
+    /// @brief Indicates whether DHCP server identifier option will be ignored
+    bool ignore_dhcp_server_identifier_;
     /// @brief Indicates whether RAI link-selection suboptions will be ignored
     bool ignore_rai_link_selection_;
+    /// @brief Indicates whether exclude .0 .255 from subnets bigger than /24.
+    bool exclude_first_last_24_;
     //@}
 
     /// @brief Flag which indicates if the server should do host reservations
