@@ -211,9 +211,9 @@ TEST(PgSqlOpenTest, OpenDatabase) {
 
     // Check for extended info tables.
     const char* EX_INFO = "extended-info-tables=true";
-    EXPECT_THROW(LeaseMgrFactory::create(connectionString(
-        PGSQL_VALID_TYPE, VALID_NAME, VALID_HOST, VALID_USER, VALID_PASSWORD, EX_INFO)),
-        NotImplemented);
+    EXPECT_NO_THROW(LeaseMgrFactory::create(connectionString(
+        PGSQL_VALID_TYPE, VALID_NAME, VALID_HOST, VALID_USER, VALID_PASSWORD, EX_INFO)));
+    LeaseMgrFactory::destroy();
 
     // Tidy up after the test
     destroyPgSQLSchema();
@@ -1166,118 +1166,154 @@ TEST_F(PgSqlLeaseMgrTest, checkLimits6) {
 /// @brief Checks if the backends call the callbacks when an
 /// IPv4 lease is added.
 TEST_F(PgSqlLeaseMgrTest, trackAddLease4) {
-    testTrackAddLease4(false);
+    // It is unnecessary to lock the lease in ST. The backend does not
+    // provide the MT-safe context for the callbacks.
+    testTrackAddLease4(false, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv4 lease is added.
 TEST_F(PgSqlLeaseMgrTest, trackAddLease4MultiThreading) {
     MultiThreadingMgr::instance().setMode(true);
-    testTrackAddLease4(true);
+    // The lease should be locked in the MT mode. The backend does not
+    // provide an MT-safe context.
+    testTrackAddLease4(true, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv6 address lease is added.
 TEST_F(PgSqlLeaseMgrTest, trackAddLeaseNA) {
-    testTrackAddLeaseNA(false);
+    // It is unnecessary to lock the lease in ST. The backend does not
+    // provide the MT-safe context for the callbacks.
+    testTrackAddLeaseNA(false, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv6 address lease is added.
 TEST_F(PgSqlLeaseMgrTest, trackAddLeaseNAMultiThreading) {
     MultiThreadingMgr::instance().setMode(true);
-    testTrackAddLeaseNA(true);
+    // The lease should be locked in the MT mode. The backend does not
+    // provide an MT-safe context.
+    testTrackAddLeaseNA(true, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv6 prefix lease is added.
 TEST_F(PgSqlLeaseMgrTest, trackAddLeasePD) {
-    testTrackAddLeasePD(false);
+    // It is unnecessary to lock the lease in ST. The backend does not
+    // provide the MT-safe context for the callbacks.
+    testTrackAddLeasePD(false, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv6 prefix lease is added.
 TEST_F(PgSqlLeaseMgrTest, trackAddLeasePDMultiThreading) {
     MultiThreadingMgr::instance().setMode(true);
-    testTrackAddLeasePD(true);
+    // The lease should be locked in the MT mode. The backend does not
+    // provide an MT-safe context.
+    testTrackAddLeasePD(true, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv4 lease is updated.
 TEST_F(PgSqlLeaseMgrTest, trackUpdateLease4) {
-    testTrackUpdateLease4(false);
+    // It is unnecessary to lock the lease in ST. The backend does not
+    // provide the MT-safe context for the callbacks.
+    testTrackUpdateLease4(false, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv4 lease is updated.
 TEST_F(PgSqlLeaseMgrTest, trackUpdateLease4MultiThreading) {
     MultiThreadingMgr::instance().setMode(true);
-    testTrackUpdateLease4(true);
+    // The lease should be locked in the MT mode. The backend does not
+    // provide an MT-safe context.
+    testTrackUpdateLease4(true, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv6 address lease is updated.
 TEST_F(PgSqlLeaseMgrTest, trackUpdateLeaseNA) {
-    testTrackUpdateLeaseNA(false);
+    // It is unnecessary to lock the lease in ST. The backend does not
+    // provide the MT-safe context for the callbacks.
+    testTrackUpdateLeaseNA(false, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv6 address lease is updated.
 TEST_F(PgSqlLeaseMgrTest, trackUpdateLeaseNAMultiThreading) {
     MultiThreadingMgr::instance().setMode(true);
-    testTrackUpdateLeaseNA(true);
+    // The lease should be locked in the MT mode. The backend does not
+    // provide an MT-safe context.
+    testTrackUpdateLeaseNA(true, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv6 prefix lease is updated.
 TEST_F(PgSqlLeaseMgrTest, trackUpdateLeasePD) {
-    testTrackUpdateLeasePD(false);
+    // It is unnecessary to lock the lease in ST. The backend does not
+    // provide the MT-safe context for the callbacks.
+    testTrackUpdateLeasePD(false, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv6 prefix lease is updated.
 TEST_F(PgSqlLeaseMgrTest, trackUpdateLeasePDMultiThreading) {
     MultiThreadingMgr::instance().setMode(true);
-    testTrackUpdateLeasePD(true);
+    // The lease should be locked in the MT mode. The backend does not
+    // provide an MT-safe context.
+    testTrackUpdateLeasePD(true, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv4 lease is deleted.
 TEST_F(PgSqlLeaseMgrTest, trackDeleteLease4) {
-    testTrackDeleteLease4(false);
+    // It is unnecessary to lock the lease in ST. The backend does not
+    // provide the MT-safe context for the callbacks.
+    testTrackDeleteLease4(false, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv4 lease is deleted.
 TEST_F(PgSqlLeaseMgrTest, trackDeleteLease4MultiThreading) {
     MultiThreadingMgr::instance().setMode(true);
-    testTrackDeleteLease4(true);
+    // The lease should be locked in the MT mode. The backend does not
+    // provide an MT-safe context.
+    testTrackDeleteLease4(true, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv6 address lease is deleted.
 TEST_F(PgSqlLeaseMgrTest, trackDeleteLeaseNA) {
-    testTrackDeleteLeaseNA(false);
+    // It is unnecessary to lock the lease in ST. The backend does not
+    // provide the MT-safe context for the callbacks.
+    testTrackDeleteLeaseNA(false, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv6 address lease is deleted.
 TEST_F(PgSqlLeaseMgrTest, trackDeleteLeaseNAMultiThreading) {
     MultiThreadingMgr::instance().setMode(true);
-    testTrackDeleteLeaseNA(true);
+    // The lease should be locked in the MT mode. The backend does not
+    // provide an MT-safe context.
+    testTrackDeleteLeaseNA(true, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv6 prefix lease is deleted.
 TEST_F(PgSqlLeaseMgrTest, trackDeleteLeasePD) {
-    testTrackDeleteLeasePD(false);
+    // It is unnecessary to lock the lease in ST. The backend does not
+    // provide the MT-safe context for the callbacks.
+    testTrackDeleteLeasePD(false, false);
 }
 
 /// @brief Checks if the backends call the callbacks when an
 /// IPv6 prefix lease is deleted.
 TEST_F(PgSqlLeaseMgrTest, trackDeleteLeasePDMultiThreading) {
     MultiThreadingMgr::instance().setMode(true);
-    testTrackDeleteLeasePD(true);
+    // The lease should be locked in the MT mode. The backend does not
+    // provide an MT-safe context.
+    testTrackDeleteLeasePD(true, false);
 }
 
 /// @brief Checks that the lease manager can be recreated and its
