@@ -1,4 +1,4 @@
-// Copyright (C) 2015-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2015-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -6,10 +6,13 @@
 
 #include <config.h>
 
-#include <stats/observation.h>
 #include <exceptions/exceptions.h>
+#include <stats/observation.h>
 #include <util/chrono_time_utils.h>
+#include <util/bigints.h>
+
 #include <boost/shared_ptr.hpp>
+
 #include <gtest/gtest.h>
 
 #include <iostream>
@@ -19,6 +22,7 @@
 
 using namespace isc;
 using namespace isc::stats;
+using namespace isc::util;
 using namespace std::chrono;
 
 namespace {
@@ -51,13 +55,15 @@ public:
         a("alpha", static_cast<int64_t>(1234)), // integer
         b("beta", 12.34), // float
         c("gamma", dur1234), // duration
-        d("delta", "1234") { // string
+        d("delta", "1234"), // string
+        e("epsilon", int128_t(12e34)) { // big integer
     }
 
     Observation a;
     Observation b;
     Observation c;
     Observation d;
+    Observation e;
 };
 
 // Basic tests for the Observation constructors. This test checks whether
@@ -67,29 +73,40 @@ TEST_F(ObservationTest, constructor) {
     EXPECT_EQ(Observation::STAT_FLOAT, b.getType());
     EXPECT_EQ(Observation::STAT_DURATION, c.getType());
     EXPECT_EQ(Observation::STAT_STRING, d.getType());
+    EXPECT_EQ(Observation::STAT_BIG_INTEGER, e.getType());
 
     EXPECT_EQ(1234, a.getInteger().first);
     EXPECT_EQ(12.34, b.getFloat().first);
     EXPECT_EQ(dur1234, c.getDuration().first);
     EXPECT_EQ("1234", d.getString().first);
+    EXPECT_EQ(int128_t(12e34), e.getBigInteger().first);
 
     // Let's check that attempting to get a different type
     // than used will cause an exception.
     EXPECT_THROW(a.getFloat(), InvalidStatType);
     EXPECT_THROW(a.getDuration(), InvalidStatType);
     EXPECT_THROW(a.getString(), InvalidStatType);
+    EXPECT_THROW(a.getBigInteger(), InvalidStatType);
 
     EXPECT_THROW(b.getInteger(), InvalidStatType);
     EXPECT_THROW(b.getDuration(), InvalidStatType);
     EXPECT_THROW(b.getString(), InvalidStatType);
+    EXPECT_THROW(b.getBigInteger(), InvalidStatType);
 
     EXPECT_THROW(c.getInteger(), InvalidStatType);
     EXPECT_THROW(c.getFloat(), InvalidStatType);
     EXPECT_THROW(c.getString(), InvalidStatType);
+    EXPECT_THROW(c.getBigInteger(), InvalidStatType);
 
     EXPECT_THROW(d.getInteger(), InvalidStatType);
     EXPECT_THROW(d.getFloat(), InvalidStatType);
     EXPECT_THROW(d.getDuration(), InvalidStatType);
+    EXPECT_THROW(d.getBigInteger(), InvalidStatType);
+
+    EXPECT_THROW(e.getInteger(), InvalidStatType);
+    EXPECT_THROW(e.getFloat(), InvalidStatType);
+    EXPECT_THROW(e.getDuration(), InvalidStatType);
+    EXPECT_THROW(e.getString(), InvalidStatType);
 }
 
 // This test checks whether it is possible to set to an absolute value for all
@@ -99,30 +116,40 @@ TEST_F(ObservationTest, setValue) {
     EXPECT_NO_THROW(b.setValue(56e+78));
     EXPECT_NO_THROW(c.setValue(dur5678));
     EXPECT_NO_THROW(d.setValue("fiveSixSevenEight"));
-
+    EXPECT_NO_THROW(e.setValue(int128_t(43e21)));
 
     EXPECT_EQ(5678, a.getInteger().first);
     EXPECT_EQ(56e+78, b.getFloat().first);
     EXPECT_EQ(dur5678, c.getDuration().first);
     EXPECT_EQ("fiveSixSevenEight", d.getString().first);
+    EXPECT_EQ(int128_t(43e21), e.getBigInteger().first);
 
     // Now check whether setting value to a different type does
     // throw an exception
     EXPECT_THROW(a.setValue(56e+78), InvalidStatType);
     EXPECT_THROW(a.setValue(dur5678), InvalidStatType);
     EXPECT_THROW(a.setValue("fiveSixSevenEight"), InvalidStatType);
+    EXPECT_THROW(a.setValue(int128_t(43e21)), InvalidStatType);
 
     EXPECT_THROW(b.setValue(static_cast<int64_t>(5678)), InvalidStatType);
     EXPECT_THROW(b.setValue(dur5678), InvalidStatType);
     EXPECT_THROW(b.setValue("fiveSixSevenEight"), InvalidStatType);
+    EXPECT_THROW(b.setValue(int128_t(43e21)), InvalidStatType);
 
     EXPECT_THROW(c.setValue(static_cast<int64_t>(5678)), InvalidStatType);
     EXPECT_THROW(c.setValue(56e+78), InvalidStatType);
     EXPECT_THROW(c.setValue("fiveSixSevenEight"), InvalidStatType);
+    EXPECT_THROW(c.setValue(int128_t(43e21)), InvalidStatType);
 
     EXPECT_THROW(d.setValue(static_cast<int64_t>(5678)), InvalidStatType);
     EXPECT_THROW(d.setValue(56e+78), InvalidStatType);
     EXPECT_THROW(d.setValue(dur5678), InvalidStatType);
+    EXPECT_THROW(d.setValue(int128_t(43e21)), InvalidStatType);
+
+    EXPECT_THROW(e.setValue(int64_t(5678)), InvalidStatType);
+    EXPECT_THROW(e.setValue(56e+78), InvalidStatType);
+    EXPECT_THROW(e.setValue(dur5678), InvalidStatType);
+    EXPECT_THROW(e.setValue("fiveSixSevenEight"), InvalidStatType);
 }
 
 // This test checks whether it is possible to add value to existing
@@ -135,16 +162,19 @@ TEST_F(ObservationTest, addValue) {
     EXPECT_NO_THROW(b.addValue(56.78));
     EXPECT_NO_THROW(c.addValue(dur5678));
     EXPECT_NO_THROW(d.addValue("fiveSixSevenEight"));
+    EXPECT_NO_THROW(e.addValue(int128_t(43e21)));
 
     EXPECT_EQ(6912, a.getInteger().first);
     EXPECT_EQ(69.12, b.getFloat().first);
     EXPECT_EQ(dur681012, c.getDuration().first);
     EXPECT_EQ("1234fiveSixSevenEight", d.getString().first);
+    EXPECT_EQ(int128_t(12e34) + int128_t(43e21), e.getBigInteger().first);
 
     ASSERT_EQ(a.getSize(), 2);
     ASSERT_EQ(b.getSize(), 2);
     ASSERT_EQ(c.getSize(), 2);
     ASSERT_EQ(d.getSize(), 2);
+    ASSERT_EQ(e.getSize(), 2);
 }
 
 // This test checks if collecting more than one sample
@@ -153,37 +183,42 @@ TEST_F(ObservationTest, moreThanOne) {
     // Arrays of 4 types of samples
     int64_t int_samples[3] = {1234, 6912, 5678};
     double float_samples[3] = {12.34, 69.12, 56e+78};
-    StatsDuration duration_samples[3] = {dur1234,
-        dur681012, dur5678};
+    StatsDuration duration_samples[3] = {dur1234, dur681012, dur5678};
     std::string string_samples[3] = {"1234", "1234fiveSixSevenEight", "fiveSixSevenEight"};
+    int128_t bigint_samples[3] = {int128_t(12e34), int128_t(12e34) + int128_t(43e21),
+                                  int128_t(43e21)};
 
     EXPECT_NO_THROW(a.addValue(static_cast<int64_t>(5678)));
     EXPECT_NO_THROW(b.addValue(56.78));
     EXPECT_NO_THROW(c.addValue(dur5678));
     EXPECT_NO_THROW(d.addValue("fiveSixSevenEight"));
+    EXPECT_NO_THROW(e.addValue(int128_t(43e21)));
 
     EXPECT_NO_THROW(a.setValue(static_cast<int64_t>(5678)));
     EXPECT_NO_THROW(b.setValue(56e+78));
     EXPECT_NO_THROW(c.setValue(dur5678));
     EXPECT_NO_THROW(d.setValue("fiveSixSevenEight"));
+    EXPECT_NO_THROW(e.setValue(int128_t(43e21)));
 
     ASSERT_EQ(a.getSize(), 3);
     ASSERT_EQ(b.getSize(), 3);
     ASSERT_EQ(c.getSize(), 3);
     ASSERT_EQ(d.getSize(), 3);
+    ASSERT_EQ(e.getSize(), 3);
 
     ASSERT_NO_THROW(a.getIntegers());
     ASSERT_NO_THROW(b.getFloats());
     ASSERT_NO_THROW(c.getDurations());
     ASSERT_NO_THROW(d.getStrings());
+    ASSERT_NO_THROW(e.getBigIntegers());
 
     std::list<IntegerSample> samples_int = a.getIntegers(); // List of all integer samples
     std::list<FloatSample> samples_float = b.getFloats(); // List of all float samples
     std::list<DurationSample> samples_dur = c.getDurations(); // List of all duration samples
     std::list<StringSample> samples_str = d.getStrings(); // List of all string samples
+    std::list<BigIntegerSample> samples_bigint = e.getBigIntegers(); // List of all big integer samples
 
     uint32_t i = 2; // Index pointed to the end of array of samples
-
     for (std::list<IntegerSample>::iterator it = samples_int.begin(); it != samples_int.end(); ++it) {
         EXPECT_EQ(int_samples[i], static_cast<int64_t>((*it).first));
         --i;
@@ -203,6 +238,11 @@ TEST_F(ObservationTest, moreThanOne) {
         EXPECT_EQ(string_samples[i], (*it).first);
         --i;
     }
+    i = 2;
+    for (BigIntegerSample const& sample : samples_bigint) {
+        EXPECT_EQ(bigint_samples[i], sample.first);
+        --i;
+    }
 }
 
 // This test checks whether the size of storage
@@ -213,27 +253,32 @@ TEST_F(ObservationTest, getSize) {
     ASSERT_EQ(b.getSize(), 1);
     ASSERT_EQ(c.getSize(), 1);
     ASSERT_EQ(d.getSize(), 1);
+    ASSERT_EQ(e.getSize(), 1);
 
     a.addValue(static_cast<int64_t>(5678));
     b.addValue(56.78);
     c.addValue(dur5678);
     d.addValue("fiveSixSevenEight");
+    e.addValue(int128_t(43e21));
 
     EXPECT_NO_THROW(a.getSize());
     EXPECT_NO_THROW(b.getSize());
     EXPECT_NO_THROW(c.getSize());
     EXPECT_NO_THROW(d.getSize());
+    EXPECT_NO_THROW(e.getSize());
 
     // Check if size of storages is equal to 2
     ASSERT_EQ(a.getSize(), 2);
     ASSERT_EQ(b.getSize(), 2);
     ASSERT_EQ(c.getSize(), 2);
     ASSERT_EQ(d.getSize(), 2);
+    ASSERT_EQ(e.getSize(), 2);
 
     a.setValue(static_cast<int64_t>(5678));
     b.setValue(56e+78);
     c.setValue(dur5678);
     d.setValue("fiveSixSevenEight");
+    e.setValue(int128_t(43e21));
 
     EXPECT_NO_THROW(a.getSize());
     EXPECT_NO_THROW(b.getSize());
@@ -245,6 +290,7 @@ TEST_F(ObservationTest, getSize) {
     ASSERT_EQ(b.getSize(), 3);
     ASSERT_EQ(c.getSize(), 3);
     ASSERT_EQ(d.getSize(), 3);
+    ASSERT_EQ(e.getSize(), 3);
 }
 
 // Checks whether setting amount limits works properly
@@ -279,20 +325,25 @@ TEST_F(ObservationTest, setCountLimit) {
     for (uint32_t i = 0; i < 21; ++i) {
         d.setValue(string_samples[i]);
     }
+    for (uint32_t i = 0; i < 21; ++i) {
+        e.setValue(int128_t(int_samples[i]));
+    }
 
     // Getting all 4 types of samples after inserting 21 values
     std::list<IntegerSample> samples_int = a.getIntegers();
     std::list<FloatSample> samples_float = b.getFloats();
     std::list<DurationSample> samples_duration = c.getDurations();
     std::list<StringSample> samples_string = d.getStrings();
+    std::list<BigIntegerSample> samples_bigint = e.getBigIntegers();
 
     // Check if size of storages is equal to 20
     ASSERT_EQ(a.getSize(), 20);
     ASSERT_EQ(b.getSize(), 20);
     ASSERT_EQ(c.getSize(), 20);
     ASSERT_EQ(d.getSize(), 20);
+    ASSERT_EQ(e.getSize(), 20);
 
-    // And whether storaged values are correct
+    // And whether stored values are correct
     uint32_t i = 20; // index of the last element in array of test's samples
     for (std::list<IntegerSample>::iterator it = samples_int.begin(); it != samples_int.end(); ++it) {
         EXPECT_EQ((*it).first, int_samples[i]);
@@ -313,23 +364,31 @@ TEST_F(ObservationTest, setCountLimit) {
         EXPECT_EQ((*it).first, string_samples[i]);
         --i;
     }
+    i = 20; // index of last element in array of test's samples
+    for (BigIntegerSample const& sample : samples_bigint) {
+        EXPECT_EQ(sample.first, int_samples[i]);
+        --i;
+    }
 
     // Change size of storage to smaller one
     ASSERT_NO_THROW(a.setMaxSampleCount(10));
     ASSERT_NO_THROW(b.setMaxSampleCount(10));
     ASSERT_NO_THROW(c.setMaxSampleCount(10));
     ASSERT_NO_THROW(d.setMaxSampleCount(10));
+    ASSERT_NO_THROW(e.setMaxSampleCount(10));
 
     samples_int = a.getIntegers();
     samples_float = b.getFloats();
     samples_duration = c.getDurations();
     samples_string = d.getStrings();
+    samples_bigint = e.getBigIntegers();
 
     // Check if size of storages is equal to 10
     ASSERT_EQ(a.getSize(), 10);
     ASSERT_EQ(b.getSize(), 10);
     ASSERT_EQ(c.getSize(), 10);
     ASSERT_EQ(d.getSize(), 10);
+    ASSERT_EQ(e.getSize(), 10);
 
     // And whether storages contain only the 10 newest values
     i = 20; // index of last element in array of test's samples
@@ -352,34 +411,44 @@ TEST_F(ObservationTest, setCountLimit) {
         EXPECT_EQ((*it).first, string_samples[i]);
         --i;
     }
+    i = 20; // index of last element in array of test's samples
+    for (BigIntegerSample const& sample : samples_bigint) {
+        EXPECT_EQ(sample.first, int_samples[i]);
+        --i;
+    }
 
     // Resize max_sample_count to greater
     ASSERT_NO_THROW(a.setMaxSampleCount(50));
     ASSERT_NO_THROW(b.setMaxSampleCount(50));
     ASSERT_NO_THROW(c.setMaxSampleCount(50));
     ASSERT_NO_THROW(d.setMaxSampleCount(50));
+    ASSERT_NO_THROW(e.setMaxSampleCount(50));
 
     // Check if size of storages did not change without adding new value
     ASSERT_EQ(a.getSize(), 10);
     ASSERT_EQ(b.getSize(), 10);
     ASSERT_EQ(c.getSize(), 10);
     ASSERT_EQ(d.getSize(), 10);
+    ASSERT_EQ(e.getSize(), 10);
 
     // Add new values to each type of Observation
     a.setValue(static_cast<int64_t>(21));
     b.setValue(21.0);
     c.setValue(milliseconds(21));
     d.setValue("v");
+    e.setValue(int128_t(21));
 
     samples_int = a.getIntegers();
     samples_float = b.getFloats();
     samples_duration = c.getDurations();
     samples_string = d.getStrings();
+    samples_bigint = e.getBigIntegers();
 
     ASSERT_EQ(a.getSize(), 11);
     ASSERT_EQ(b.getSize(), 11);
     ASSERT_EQ(c.getSize(), 11);
     ASSERT_EQ(d.getSize(), 11);
+    ASSERT_EQ(e.getSize(), 11);
 
     i = 21; // index of last element in array of test's samples
     for (std::list<IntegerSample>::iterator it = samples_int.begin(); it != samples_int.end(); ++it) {
@@ -401,7 +470,11 @@ TEST_F(ObservationTest, setCountLimit) {
         EXPECT_EQ((*it).first, string_samples[i]);
         --i;
     }
-
+    i = 21; // index of last element in array of test's samples
+    for (BigIntegerSample const& sample : samples_bigint) {
+        EXPECT_EQ(sample.first, int_samples[i]);
+        --i;
+    }
 }
 
 // Checks whether setting age limits works properly
@@ -451,42 +524,50 @@ TEST_F(ObservationTest, getLimits) {
     EXPECT_EQ(b.getMaxSampleAge().first, false);
     EXPECT_EQ(c.getMaxSampleAge().first, false);
     EXPECT_EQ(d.getMaxSampleAge().first, false);
+    EXPECT_EQ(e.getMaxSampleAge().first, false);
 
     EXPECT_EQ(a.getMaxSampleCount().first, true);
     EXPECT_EQ(b.getMaxSampleCount().first, true);
     EXPECT_EQ(c.getMaxSampleCount().first, true);
     EXPECT_EQ(d.getMaxSampleCount().first, true);
+    EXPECT_EQ(e.getMaxSampleCount().first, true);
 
     EXPECT_EQ(a.getMaxSampleCount().second, 20);
     EXPECT_EQ(b.getMaxSampleCount().second, 20);
     EXPECT_EQ(c.getMaxSampleCount().second, 20);
     EXPECT_EQ(d.getMaxSampleCount().second, 20);
+    EXPECT_EQ(e.getMaxSampleCount().second, 20);
 
     // change limit to time duration
     ASSERT_NO_THROW(a.setMaxSampleAge(dur453));
     ASSERT_NO_THROW(b.setMaxSampleAge(dur453));
     ASSERT_NO_THROW(c.setMaxSampleAge(dur453));
     ASSERT_NO_THROW(d.setMaxSampleAge(dur453));
+    ASSERT_NO_THROW(e.setMaxSampleAge(dur453));
 
     EXPECT_EQ(a.getMaxSampleAge().first, true);
     EXPECT_EQ(b.getMaxSampleAge().first, true);
     EXPECT_EQ(c.getMaxSampleAge().first, true);
     EXPECT_EQ(d.getMaxSampleAge().first, true);
+    EXPECT_EQ(e.getMaxSampleAge().first, true);
 
     EXPECT_EQ(a.getMaxSampleAge().second, dur453);
     EXPECT_EQ(b.getMaxSampleAge().second, dur453);
     EXPECT_EQ(c.getMaxSampleAge().second, dur453);
     EXPECT_EQ(d.getMaxSampleAge().second, dur453);
+    EXPECT_EQ(e.getMaxSampleAge().second, dur453);
 
     EXPECT_EQ(a.getMaxSampleCount().first, false);
     EXPECT_EQ(b.getMaxSampleCount().first, false);
     EXPECT_EQ(c.getMaxSampleCount().first, false);
     EXPECT_EQ(d.getMaxSampleCount().first, false);
+    EXPECT_EQ(e.getMaxSampleCount().first, false);
 
     EXPECT_EQ(a.getMaxSampleCount().second, 20);
     EXPECT_EQ(b.getMaxSampleCount().second, 20);
     EXPECT_EQ(c.getMaxSampleCount().second, 20);
     EXPECT_EQ(d.getMaxSampleCount().second, 20);
+    EXPECT_EQ(e.getMaxSampleCount().second, 20);
 }
 
 // limit defaults are tested with StatsMgr.
@@ -525,7 +606,6 @@ TEST_F(ObservationTest, integerToJSON) {
     std::string exp = "[ [ 1234, \"" +
         isc::util::clockToText(a.getInteger().second) + "\" ]" + first_sample;
 
-    std::cout << a.getJSON()->str() << std::endl;
     EXPECT_EQ(exp, a.getJSON()->str());
 }
 
@@ -546,7 +626,6 @@ TEST_F(ObservationTest, floatToJSON) {
     std::string exp = "[ [ 1234.5, \"" +
         isc::util::clockToText(b.getFloat().second) + "\" ]" + first_sample;
 
-    std::cout << b.getJSON()->str() << std::endl;
     EXPECT_EQ(exp, b.getJSON()->str());
 }
 
@@ -564,7 +643,6 @@ TEST_F(ObservationTest, durationToJSON) {
     std::string exp = "[ [ \"01:02:03.004000\", \"" +
         isc::util::clockToText(c.getDuration().second) + "\" ]" + first_sample;
 
-    std::cout << c.getJSON()->str() << std::endl;
     EXPECT_EQ(exp, c.getJSON()->str());
 }
 
@@ -581,31 +659,50 @@ TEST_F(ObservationTest, stringToJSON) {
     std::string exp = "[ [ \"Lorem ipsum dolor sit amet\", \"" +
         isc::util::clockToText(d.getString().second) + "\" ]" + first_sample;
 
-    std::cout << d.getJSON()->str() << std::endl;
     EXPECT_EQ(exp, d.getJSON()->str());
 }
 
+// Checks whether a big integer statistic can generate proper JSON structures.
+// See https://gitlab.isc.org/isc-projects/kea/wikis/designs/Stats-design
+// for details.
+TEST_F(ObservationTest, bigIntegerToJSON) {
+    // String which contains first added sample
+    std::string first_sample = ", [ 120000000000000007304085773727301632, \"" +
+        isc::util::clockToText(e.getBigInteger().second) + "\" ] ]";
+
+    e.setValue(int128_t(43e21));
+
+    std::string exp = "[ [ 43000000000000002097152, \"" +
+        isc::util::clockToText(e.getBigInteger().second) + "\" ]" + first_sample;
+
+    EXPECT_EQ(exp, e.getJSON()->str());
+}
+
 // Checks whether reset() resets the statistics properly.
 TEST_F(ObservationTest, reset) {
     EXPECT_NO_THROW(a.addValue(static_cast<int64_t>(5678)));
     EXPECT_NO_THROW(b.addValue(56.78));
     EXPECT_NO_THROW(c.addValue(dur5678));
     EXPECT_NO_THROW(d.addValue("fiveSixSevenEight"));
+    EXPECT_NO_THROW(e.addValue(int128_t(43e21)));
 
     a.reset(); // integer
     b.reset(); // float
     c.reset(); // duration
     d.reset(); // string
+    e.reset(); // big integer
 
     EXPECT_EQ(0, a.getInteger().first);
     EXPECT_EQ(0.0, b.getFloat().first);
     EXPECT_EQ(StatsDuration::zero(), c.getDuration().first);
     EXPECT_EQ("", d.getString().first);
+    EXPECT_EQ(0, e.getBigInteger().first);
 
     ASSERT_EQ(a.getSize(), 1);
     ASSERT_EQ(b.getSize(), 1);
     ASSERT_EQ(c.getSize(), 1);
     ASSERT_EQ(d.getSize(), 1);
+    ASSERT_EQ(e.getSize(), 1);
 }
 
 // Checks whether an observation can keep its name.
@@ -614,6 +711,7 @@ TEST_F(ObservationTest, names) {
     EXPECT_EQ("beta", b.getName());
     EXPECT_EQ("gamma", c.getName());
     EXPECT_EQ("delta", d.getName());
+    EXPECT_EQ("epsilon", e.getName());
 }
 
-}
+}  // namespace
